NLSL: BL05CHSA.py File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Namespaces | Functions | Variables
BL05CHSA.py File Reference

Go to the source code of this file.

## Namespaces
| BL05CHSA

## Functions
def | BL05CHSA.read_column_data (filename)

## Variables
tuple | BL05CHSA.proc = Popen(['./nlsl'],stdin = PIPE, stderr = STDOUT)
tuple | BL05CHSA.fp = open('BL05CHSA.run')
tuple | BL05CHSA.output = proc.communicate(input = fp.read())
tuple | BL05CHSA.data = read_column_data('BL05CHSA.spc')
list | BL05CHSA.fields = data[:,0]
list | BL05CHSA.experimental = data[:,1]
list | BL05CHSA.fit = data[:,2]
tuple | BL05CHSA.integral_of_spectrum = cumsum(experimental)
tuple | BL05CHSA.normalization = abs(sum(integral_of_spectrum))
tuple | BL05CHSA.fig = figure(figsize = (9,6))
list | BL05CHSA.components = data[:,3:]
tuple | BL05CHSA.max_of_fit = max(fit)
tuple | BL05CHSA.ax = gca()
tuple | BL05CHSA.ylims = ax.get_ylim()
tuple | BL05CHSA.scale_integral = max_of_fit/max(integral_of_spectrum)
int | BL05CHSA.loc = 2
int | BL05CHSA.borderaxespad = 0
tuple | BL05CHSA.rms = mean((fit/normalization-experimental/normalization)**2)
string | BL05CHSA.horizontalalignment = 'left'
string | BL05CHSA.verticalalignment = 'top'
| BL05CHSA.transform = ax.transAxes)